@@ -460,6 +460,15 @@ public:
 	 */
 	Keydata(const char *keypath);
 
+	/**
+	 * Alternate constructor can take a define list and an optional
+	 * pathfile to parse.
+	 *
+	 * @param define list
+	 * @param keypath (filepath/section)
+	 */
+	Keydata(Define *pairs, const char *keypath = NULL);
+
 	/**
 	 * Destroy the keydata object and all allocated memory.  This
 	 * may also clear the "cache" file stream if no other keydata
